@@ -26,9 +26,10 @@ use strict;
 use warnings;
 
 our $AUTOLOAD;
-our $VERSION = '0.102';
+our $VERSION = '0.104';
 
 use Carp;
+use HTML::HTML5::Parser::Error;
 use HTML::HTML5::Parser::TagSoupParser;
 use LWP::UserAgent;
 use URI::file;
@@ -215,20 +216,23 @@ sub parse_string
 	my $text = shift;
 	my $opts = shift || {};
 	
+	$self->{'errors'} = [];
 	$opts->{'parser_used'} = 'HTML::HTML5::Parser';
 	my $dom = XML::LibXML::Document->createDocument;
 	
 	if (defined $opts->{'encoding'} || 1)
 	{
 		HTML::HTML5::Parser::TagSoupParser->parse_byte_string($opts->{'encoding'}, $text, $dom, sub{
-			my $err = \@_;
+			my $err = HTML::HTML5::Parser::Error->new(@_);
+			$self->{error_handler}->($err) if $self->{error_handler};
 			push @{$self->{'errors'}}, $err;
 			});
 	}
 	else
 	{
 		HTML::HTML5::Parser::TagSoupParser->parse_char_string($text, $dom, sub{
-			my $err = \@_;
+			my $err = HTML::HTML5::Parser::Error->new(@_);
+			$self->{error_handler}->($err) if $self->{error_handler};
 			push @{$self->{'errors'}}, $err;
 			});
 	}
@@ -290,6 +294,7 @@ sub AUTOLOAD
 		return 0;
 	}
 
+	carp "HTML::HTML5::Parser doesn't understand '$func'." if length $func;
 }
 
 =head2 Additional Methods
@@ -299,6 +304,36 @@ non-DOM data from DOM nodes.
 
 =over 8
 
+=item C<error_handler>
+
+Get/set an error handling function. Must be set to a coderef or undef.
+
+The error handling function will be called with a single parameter, a
+L<HTML::HTML5::Parser::Error> object.
+
+=cut
+
+sub error_handler
+{
+	my $self = shift;
+	$self->{error_handler} = shift if @_;
+	return $self->{error_handler};
+}
+
+=item C<errors>
+
+Returns a list of errors that occurred during the last parse.
+
+See L<HTML::HTML5::Parser::Error>.
+
+=cut
+
+sub errors
+{
+	my $self = shift;
+	return @{ $self->{errors} };
+}
+
 =item C<compat_mode>
 
   $mode = $parser->compat_mode( $doc );
@@ -383,6 +418,7 @@ sub source_line
 	}
 }
 
+sub DESTROY {}
 
 =back
 
@@ -401,9 +437,9 @@ Toby Inkster, E<lt>tobyink@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2007-2010 by Wakaba
+Copyright (C) 2007-2011 by Wakaba
 
-Copyright (C) 2009-2010 by Toby Inkster
+Copyright (C) 2009-2011 by Toby Inkster
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.1 or,
